/* ============================================================
 * File  : tetrahedron.cpp
 * Author: Stephane Gibault
 * Date  : Sun Feb 4 2007
 * Description :
 *
 * 
 *  (C) 2007 by Stephane Gibault
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * ============================================================ */
#include <QtGui>
#include <QImageReader>
#include "imageeditor.h"

imageeditor::imageeditor ( QWidget * parent )
    : QLabel(parent)
{
	myparent = parent;
	startcrop = 0;
	fadex=50;
	fadey=50;
	this->setMouseTracking(true);
	this->setScaledContents(true);
	//setAttribute(Qt::WA_PaintOnScreen);
}

void imageeditor::setImage(QPixmap pntimg2crop, QString pathname, int width, int height)
{
	path2crop = pathname;
	img2crop = pntimg2crop;
	img2resu = pntimg2crop;
	img2save = pntimg2crop;
	img32b = img2save.toImage();
	img32b = img32b.convertToFormat ( QImage::Format_ARGB32_Premultiplied, Qt::AutoColor );
	iwidth = width;
	iheight = height;
	realw = width;
	realh = height;
}

void imageeditor::mousePressEvent ( QMouseEvent * event ) 
{
	if ( startcrop == 3 )
	{
		crop_dx = event->x();
		crop_dy = event->y();
		startcrop = 1; 
	}
	else
	{
		if ( startcrop == 4 )
		{
			oldmx = event->x();
			oldmy = event->y();
			startcrop = 2;
		}
	}
}

void imageeditor::mouseReleaseEvent ( QMouseEvent * event )  
{
	if ( startcrop == 1 || startcrop == 2 )
	{
		if ( crop_dx > event->x() )
		{
			crop_ex = crop_dx;
			crop_dx = event->x();
		}
		if ( crop_dy > event->y() )
		{
			crop_ey = crop_dy;
			crop_dy = event->y();
		}
		startcrop = 4;
	}
}

void imageeditor::gocrop()
{
	img2resu = img2resu.copy ( crop_dx,crop_dy,crop_ex - crop_dx,crop_ey - crop_dy );
	img2save = img2resu;
	this->setPixmap(img2resu);
	this->setGeometry ((myparent->width() - img2resu.width())/2,(myparent->height() - img2resu.height())/2,img2resu.width(),img2resu.height());
	this->repaint();
	realw = img2resu.width();
	realh = img2resu.height();
}

void imageeditor::mouseMoveEvent ( QMouseEvent * event )
{
	if ( startcrop == 1 )
	{
		crop_ex = event->x();
		crop_ey = event->y();
		this->repaint();
	}
	else
	{
		if ( startcrop == 2 )
		{
			if (!(event->buttons() & Qt::LeftButton)) return;
			crop_dx = crop_dx + (event->x()-oldmx);
			crop_dy = crop_dy + (event->y()-oldmy);

			crop_ex = crop_ex + (event->x()-oldmx);
			crop_ey = crop_ey + (event->y()-oldmy);

			oldmx = event->x();
			oldmy = event->y();
			this->repaint();
		}
		else
		{
			if ( startcrop == 0 )
			{
				if (!(event->buttons() & Qt::LeftButton)) return;
				fadex = ((float)event->x() / (float)realw )*(float)100;
				fadey = ((float)event->y() / (float)realh)*(float)100;
				emit deplace_fade();
			}
		}
	}
}

void imageeditor::paintEvent(QPaintEvent *)
{
	QPainter p;
	p.begin(this);
	p.drawPixmap ( 0,0,img2resu );
	if ( startcrop == 1 || startcrop == 2 || startcrop == 4 )
	{
		p.fillRect ( 0, 0, iwidth, iheight, QBrush( QColor(20,20,20,160), Qt::SolidPattern ) );
		if ( crop_ex > crop_dx )
		{
			if ( crop_ey > crop_dy )
			{
				p.drawPixmap ( crop_dx, crop_dy, img2resu, crop_dx, crop_dy, crop_ex - crop_dx, crop_ey - crop_dy  );
			}
			else
			{
				p.drawPixmap ( crop_dx, crop_ey, img2resu, crop_dx, crop_ey, crop_ex - crop_dx, crop_dy - crop_ey  );
			}
		}
		else
		{
			if ( crop_ey > crop_dy )
			{
				p.drawPixmap ( crop_ex, crop_dy, img2resu, crop_ex, crop_dy, crop_dx - crop_ex, crop_ey - crop_dy  );
			}
			else
			{
				p.drawPixmap ( crop_ex, crop_ey, img2resu, crop_ex, crop_ey, crop_dx - crop_ex, crop_dy - crop_ey  );
			}
		}
		p.setPen ( Qt::DotLine );
		p.setPen ( Qt::white );
		p.drawRect ( crop_dx, crop_dy, crop_ex - crop_dx, crop_ey - crop_dy );
	}
	p.end();
}

