/* ============================================================
 * File  : tetrahedron.cpp
 * Author: Stephane Gibault
 * Date  : Sun Feb 4 2007
 * Description :
 *
 * 
 *  (C) 2007 by Stephane Gibault
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * ============================================================ */
#include <QtGui>
#include <QDropEvent>
#include "timeline.h"

timeline::timeline ( QWidget * parent )
    : QFrame(parent)
{
	myparent = parent;
	this->setAcceptDrops(true);
	this->setMouseTracking (true);
	QLabel *winsert = new QLabel(this);
	pntinsert = winsert;
	max_diapo = -1;
	lengthtimeline = 0;
	postimeline = 0;

	insert_movie = new QMovie(":/new/prefix2/Interface/Theme/insertion.gif");
	if ( insert_movie->isValid() == false )
	{
		qDebug() << "ERROR LOADING PICTURE INSERT IN TIMELINE";
	}
	else
	{
		insert_movie->setCacheMode( QMovie::CacheAll );
		insert_movie->jumpToFrame( 0 );
	}
	pntinsert->setGeometry( 100, 3, 32, 32);
	pntinsert->setMovie ( insert_movie );
	pntinsert->hide();
	//
	removeDiapo = new QAction(tr("Supprimer la diapositive selectionnee"), this);
	removeDiapo->setIcon ( QIcon(":/new/prefix2/Interface/Theme/trash_empty.png") );
	editDiapo = new QAction(tr("Editer la diapositive"), this);
	editDiapo->setIcon ( QIcon(":/new/prefix2/Interface/Theme/applications_graphics.png") );
	copyDiapo = new QAction(tr("Copier les coordonnees"), this);
	copyDiapo->setIcon ( QIcon(":/new/prefix2/Interface/Theme/copy.png") );
	pasteDiapo = new QAction(tr("Coller les coordonnees"), this);
	pasteDiapo->setIcon ( QIcon(":/new/prefix2/Interface/Theme/editpaste.png") );
	//removeDiapo->setShortcut(tr("Ctrl+N"));
	connect(removeDiapo, SIGNAL(triggered()), this, SLOT(deletethis()));
	connect(editDiapo, SIGNAL(triggered()), this, SLOT(editthis()));
	connect(copyDiapo, SIGNAL(triggered()), this, SLOT(copythis()));
	connect(pasteDiapo, SIGNAL(triggered()), this, SLOT(pastethis()));
}

void timeline::deletethis()
{
	emit dia_delete();
}

void timeline::editthis()
{
	emit dia_edit();
}

void timeline::copythis()
{
	emit dia_copy();
}

void timeline::pastethis()
{
	emit dia_paste();
}

void timeline::contextMenuEvent(QContextMenuEvent *event)
{
	if ( max_diapo >= 0 )
	{
		QMenu menu(this);
		menu.addAction(removeDiapo);
		menu.addAction(editDiapo);
		menu.addAction(copyDiapo);
		menu.addAction(pasteDiapo);
		menu.exec(event->globalPos());
	}
}

void timeline::dragEnterEvent(QDragEnterEvent *event)
{
	event->acceptProposedAction();
}

void timeline::dragMoveEvent( QDragMoveEvent * event ) 
{
	if ( event->pos().x() < (max_diapo+1) * 107 && max_diapo > -1 )
	{
		pntinsert->setGeometry( (int)(((event->pos().x() / 107)*107))-5, 0, 22, 22);
	}
	else
	{
		pntinsert->setGeometry( (int)(((max_diapo+1)*107))-5, 0, 22, 22);
	}
	if ( pntinsert->isVisible() == false )
	{
		pntinsert->raise();
		pntinsert->show();
		insert_movie->start();
	}
	if ( (event->pos().x() - postimeline) > (lengthtimeline - 100) )
	{
		emit move_left();
	}  
	if ( (event->pos().x() - postimeline) < 100 )
	{
		emit move_right();
	} 
}

void timeline::dropEvent(QDropEvent *event)
{
	drop_x = event->pos().x();
	drop_y = event->pos().y();
	pntinsert->hide();
	insert_movie->stop();

	if ( event->mimeData()->hasUrls() == true )
	{
		QList<QUrl> myurl = event->mimeData()->urls();
		int wl_importation = 0;
		while ( wl_importation < myurl.count() - 1 )
		{
			wl_pathname = myurl[wl_importation].toString(QUrl::None);
			wl_importation++;
			event->acceptProposedAction();
			emit godrop();	
		}
	}
	else
	{
		if (event->mimeData()->hasText())
		{
			wl_pathname = event->mimeData()->text();
			event->acceptProposedAction();
			emit godrop();	
		}
	}
}

void timeline::mouseMoveEvent(QMouseEvent *event)
{
}

void timeline::dragLeaveEvent ( QDragLeaveEvent * event )
{
	pntinsert->hide();
	insert_movie->stop();
}

Qt::DropActions timeline::supportedDropActions () const
{
	// returns what actions are supported when dropping
	return Qt::CopyAction | Qt::MoveAction;
}

